@@ -72,6 +72,7 @@ class User(Resource):
     trust_data: TrustDataV1 = field(metadata={'data_key': 'TrustData'})
     serial_numbers: List[str] = field(default_factory=list, metadata={'data_key': 'SerialNumbers'})
     roles: List[str] = field(default_factory=list, metadata={'data_key': 'Roles', 'allow_none': True})
+    is_deleted: bool = False
     Schema: ClassVar[Type[Schema]] = Schema
 
     @property
@@ -102,8 +103,8 @@ class Device(Resource):
     last_login: datetime = field(metadata={"marshmallow_field": NanoTimestampField(data_key='LastLogin')})
     login_count: int = field(metadata={'data_key': 'LoginCount'})
     ownership: str = field(metadata={'data_key': 'Ownership',
-                                     'validate': validate.OneOf(DeviceOwnership.choices() +
-                                                                ['UNKNOWN', 'Undefined', ''])})
+                                     'validate': validate.OneOf(
+                                         DeviceOwnership.choices() + ['UNKNOWN', 'Undefined', ''])})
     platform: str = field(metadata={'data_key': 'Platform'})
     model: str = field(metadata={'data_key': 'Model'})
     architecture: str = field(metadata={'data_key': 'Architecture'})
@@ -116,6 +117,7 @@ class Device(Resource):
     trust_data: TrustDataV1 = field(metadata={'data_key': 'TrustData'})
     emails: List[str] = field(default_factory=list, metadata={'data_key': 'Emails'})
     roles: List[str] = field(default_factory=list, metadata={'data_key': 'Roles', 'allow_none': True})
+    is_deleted: bool = False
     Schema: ClassVar[Type[Schema]] = Schema
 
     @property
